@@ -12,6 +12,7 @@
 #endif
 #include "Auth.hpp"
 #include "OptionContainer.hpp"
+#include "LOptionContainer.hpp"
 
 #include <iostream>
 #include <syslog.h>
@@ -19,6 +20,7 @@
 // GLOBALS
 
 extern OptionContainer o;
+extern thread_local std::string thread_id;
 extern bool is_daemonised;
 
 extern authcreate_t proxycreate;
@@ -27,6 +29,7 @@ extern authcreate_t identcreate;
 extern authcreate_t ipcreate;
 extern authcreate_t portcreate;
 extern authcreate_t headercreate;
+
 #ifdef PRT_DNSAUTH
 extern authcreate_t dnsauthcreate;
 #endif
@@ -58,29 +61,32 @@ String AuthPlugin::getPluginName()
 {
     return pluginName;
 }
+
 // determine what filter group the given username is in
 // return -1 when user not found
-int AuthPlugin::determineGroup(std::string &user, int &fg)
+int AuthPlugin::determineGroup(std::string &user, int &fg, ListContainer & uglc)
 {
     if (user.length() < 1 || user == "-") {
         return DGAUTH_NOMATCH;
     }
     String u(user);
+    String lastcategory;
     u.toLower(); // since the filtergroupslist is read in in lowercase, we should do this.
     user = u.toCharArray(); // also pass back to ConnectionHandler, so appears lowercase in logs
     String ue(u);
     ue += "=";
 
-    char *i = o.filter_groups_list.findStartsWithPartial(ue.toCharArray());
+    //char *i = ldl->filter_groups_list.findStartsWithPartial(ue.toCharArray(), lastcategory);
+    char *i = uglc.findStartsWithPartial(ue.toCharArray(), lastcategory);
 
     if (i == NULL) {
 #ifdef DGDEBUG
-        std::cout << "User not in filter groups list: " << ue << std::endl;
+        std::cerr << "User not in filter groups list: " << ue << std::endl;
 #endif
         return DGAUTH_NOUSER;
     }
 #ifdef DGDEBUG
-    std::cout << "User found: " << i << std::endl;
+    std::cerr << "User found: " << i << std::endl;
 #endif
     ue = i;
     if (ue.before("=") == u) {
@@ -89,14 +95,15 @@ int AuthPlugin::determineGroup(std::string &user, int &fg)
         if (l < 1 || l > 2) {
             return DGAUTH_NOUSER;
         }
-        fg = ue.toInteger();
-        if (fg > o.numfg) {
+        int t;
+        t = ue.toInteger();
+        if (t > o.numfg) {
             return DGAUTH_NOUSER;
         }
-        if (fg > 0) {
-            fg--;
+        if (t > 0) {
+            fg = --t;
+            return DGAUTH_OK;
         }
-        return DGAUTH_OK;
     }
     return DGAUTH_NOUSER;
 }
@@ -108,67 +115,67 @@ AuthPlugin *auth_plugin_load(const char *pluginConfigPath)
 
     if (cv.readVar(pluginConfigPath, "=") > 0) {
         if (!is_daemonised) {
-            std::cerr << "Unable to load plugin config: " << pluginConfigPath << std::endl;
+            std::cerr << thread_id << "Unable to load plugin config: " << pluginConfigPath << std::endl;
         }
-        syslog(LOG_ERR, "Unable to load plugin config %s", pluginConfigPath);
+        syslog(LOG_ERR, "%sUnable to load plugin config %s", thread_id.c_str(), pluginConfigPath);
         return NULL;
     }
 
     String plugname(cv["plugname"]);
     if (plugname.length() < 1) {
         if (!is_daemonised) {
-            std::cerr << "Unable read plugin config plugname variable: " << pluginConfigPath << std::endl;
+            std::cerr << thread_id << "Unable read plugin config plugname variable: " << pluginConfigPath << std::endl;
         }
-        syslog(LOG_ERR, "Unable read plugin config plugname variable %s", pluginConfigPath);
+        syslog(LOG_ERR, "%sUnable read plugin config plugname variable %s", thread_id.c_str(), pluginConfigPath);
         return NULL;
     }
 
     if (plugname == "proxy-basic") {
 #ifdef DGDEBUG
-        std::cout << "Enabling proxy-basic auth plugin" << std::endl;
+        std::cerr << thread_id << "Enabling proxy-basic auth plugin" << std::endl;
 #endif
         return proxycreate(cv);
     }
 
     if (plugname == "proxy-digest") {
 #ifdef DGDEBUG
-        std::cout << "Enabling proxy-digest auth plugin" << std::endl;
+        std::cerr << thread_id << "Enabling proxy-digest auth plugin" << std::endl;
 #endif
         return digestcreate(cv);
     }
 
-    if (plugname == "proxy-header") {
-#ifdef DGDEBUG
-        std::cout << "Enabling proxy-header auth plugin" << std::endl;
-#endif
-        return headercreate(cv);
-    }
-
     if (plugname == "ident") {
 #ifdef DGDEBUG
-        std::cout << "Enabling ident server auth plugin" << std::endl;
+        std::cerr << thread_id << "Enabling ident server auth plugin" << std::endl;
 #endif
         return identcreate(cv);
     }
 
     if (plugname == "ip") {
 #ifdef DGDEBUG
-        std::cout << "Enabling IP-based auth plugin" << std::endl;
+        std::cerr << thread_id << "Enabling IP-based auth plugin" << std::endl;
 #endif
         return ipcreate(cv);
     }
 
     if (plugname == "port") {
 #ifdef DGDEBUG
-        std::cout << "Enabling port-based auth plugin" << std::endl;
+        std::cerr << thread_id << "Enabling port-based auth plugin" << std::endl;
 #endif
         return portcreate(cv);
     }
 
+    if (plugname == "proxy-header") {
+#ifdef DGDEBUG
+        std::cerr << thread_id << "Enabling proxy-header auth plugin" << std::endl;
+#endif
+        return headercreate(cv);
+    }
+
 #ifdef PRT_DNSAUTH
     if (plugname == "dnsauth") {
 #ifdef DGDEBUG
-        std::cout << "Enabling DNS-based auth plugin" << std::endl;
+        std::cerr << thread_id << "Enabling DNS-based auth plugin" << std::endl;
 #endif
         return dnsauthcreate(cv);
     }
@@ -177,30 +184,32 @@ AuthPlugin *auth_plugin_load(const char *pluginConfigPath)
 #ifdef ENABLE_NTLM
     if (plugname == "proxy-ntlm") {
 #ifdef DGDEBUG
-        std::cout << "Enabling proxy-NTLM auth plugin" << std::endl;
+        std::cerr << thread_id << "Enabling proxy-NTLM auth plugin" << std::endl;
 #endif
         return ntlmcreate(cv);
     }
 #endif
+
+
 #ifdef __SSLMITM
 //	if (plugname == "ssl") {
 #ifdef DGDEBUG
-//		std::cout << "Enabling SSL login/core auth plugin" << std::endl;
+//		std::cerr << "Enabling SSL login/core auth plugin" << std::endl;
 #endif
 //		return sslcorecreate(cv);
 //	}
 
 //	if (plugname == "core") {
 #ifdef DGDEBUG
-//		std::cout << "Enabling SSL login/core auth plugin" << std::endl;
+//		std::cerr << "Enabling SSL login/core auth plugin" << std::endl;
 #endif
 //		return sslcorecreate(cv);
 //	}
 #endif //__SSLMITM
 
     if (!is_daemonised) {
-        std::cerr << "Unable to load plugin: " << pluginConfigPath << std::endl;
+        std::cerr << thread_id << "Unable to load plugin: " << pluginConfigPath << std::endl;
     }
-    syslog(LOG_ERR, "Unable to load plugin %s", pluginConfigPath);
+    syslog(LOG_ERR, "%sUnable to load plugin %s", thread_id.c_str(), pluginConfigPath);
     return NULL;
 }
