@@ -42,8 +42,6 @@ extern thread_local std::string thread_id;
 
 // Constructor - set default values
 ListContainer::ListContainer()
-    : refcount(0), parent(false), filedate(0), used(false), bannedpfiledate(0), exceptionpfiledate(0), weightedpfiledate(0), blanketblock(false), blanket_ip_block(false), blanketsslblock(false), blanketssl_ip_block(false), sourceisexception(false), sourcestartswith(false), sourcefilters(0), data(NULL), current_graphdata_size(0), realgraphdata(NULL), maxchildnodes(0), graphitems(0), data_length(0), data_memory(0), items(0), isSW(false), issorted(false), graphused(false), force_quick_search(false),
-    /*sthour(0), stmin(0), endhour(0), endmin(0),*/ istimelimited(false), is_iplist(false)
 {
 }
 
@@ -130,7 +128,7 @@ bool ListContainer::previousUseItem(const char *filename, bool startswith, int f
 
 // for phrase lists - read in the given file, which may be an exception list
 // inherit category and time limits from parent
-bool ListContainer::readPhraseList(const char *filename, bool isexception, int catindex, int timeindex, bool incref)
+bool ListContainer::readPhraseList(const char *filename, bool isexception, int catindex, int timeindex, bool incref, int nlimit)
 {
     // only increment refcount on first read, not read of included files
     // (includes get amalgamated, unlike item lists)
@@ -179,12 +177,12 @@ bool ListContainer::readPhraseList(const char *filename, bool isexception, int c
             if (caseinsensitive)
                 line.toLower();
             if (line.startsWith("<"))
-                readPhraseListHelper(line, isexception, catindex, timeindex);
+                readPhraseListHelper(line, isexception, catindex, timeindex, nlimit);
             // handle included list files
             else if (line.startsWith(".")) {
                 temp = line.after(".include<").before(">");
                 if (temp.length() > 0) {
-                    if (!readPhraseList(temp.toCharArray(), isexception, catindex, timeindex, false)) {
+                    if (!readPhraseList(temp.toCharArray(), isexception, catindex, timeindex, false, nlimit)) {
                         listfile.close();
                         return false;
                     }
@@ -232,10 +230,18 @@ bool ListContainer::readPhraseList(const char *filename, bool isexception, int c
 }
 
 // for phrase lists - helper function for readPhraseList
-void ListContainer::readPhraseListHelper(String line, bool isexception, int catindex, int timeindex)
+void ListContainer::readPhraseListHelper(String line, bool isexception, int catindex, int timeindex, int &nlimit)
 {
     // read in weighting value, if there
-    int weighting = line.after("><").before(">").toInteger();
+    //  1st check for % weighting
+   int weighting = line.after("><").before("%>").toInteger();
+   if (weighting != 0)     // it is a %
+   {
+       weighting = (weighting * nlimit) / 100;
+   } else {
+       // check for normal weighting
+        weighting = line.after("><").before(">").toInteger();
+   }
     // defaults to 0
     int type;
     if (weighting != 0) {
@@ -340,7 +346,7 @@ bool ListContainer::addToItemListPhrase(const char *s, size_t len, int type, int
 
 bool ListContainer::ifsreadItemList(std::istream *input, int len, bool checkendstring, const char *endstring, bool do_includes, bool startswith, int filters)
 {
-    int mem_used = 2;
+    unsigned int mem_used = 2;
     RegExp re;
     re.comp("^.*\\:[0-9]+\\/.*");
     RegResult Rre;
@@ -512,7 +518,7 @@ bool ListContainer::readItemList(const char *filename, bool startswith, int filt
 #ifdef DGDEBUG
     std::cerr << thread_id << filename << std::endl;
 #endif
-    struct stat s;
+    //struct stat s;
     filedate = getFileDate(filename);
     size_t len = 0;
     try {
@@ -1182,7 +1188,7 @@ void ListContainer::graphSearch(std::map<std::string, std::pair<unsigned int, in
 
     off_t sl;
     off_t ppos;
-    off_t currnode;
+    off_t currnode = 0;
     int *graphdata = realgraphdata;
     off_t ml;
     char p;
@@ -1817,7 +1823,7 @@ int ListContainer::getCategoryIndex(String *lcat)
     return l;
 }
 
-String ListContainer::getListCategoryAt(int index, int *catindex)
+String ListContainer::getListCategoryAt(unsigned int index, unsigned int *catindex)
 {
     //category index of -1 indicates uncategorised list
     if ((index >= categoryindex.size()) || (categoryindex[index] < 0)) {
@@ -1831,7 +1837,7 @@ String ListContainer::getListCategoryAt(int index, int *catindex)
     return listcategory[categoryindex[index]];
 }
 
-String ListContainer::getListCategoryAtD(int index)
+String ListContainer::getListCategoryAtD(unsigned int index)
 {
     //category index of -1 indicates uncategorised list
     if ((index < 0) || (index >= listcategory.size())) {
