@@ -33,9 +33,10 @@ class ListManager
     int newStdinItemList(bool startswith, int filters, bool parent );
     // create a new phrase list. re-uses existing lists, but cannot check nested lists (known limitation).
     // does not call readPhraseList. (checkme: why?)
-    int newPhraseList(const char *exception, const char *banned, const char *weighted);
+    int newPhraseList(const char *exception, const char *banned, const char *weighted, int nlimit);
 
-    bool readbplfile(const char *banned, const char *exception, const char *weighted, unsigned int &list, bool force_quick_search);
+    bool readbplfile(const char *banned, const char *exception, const char *weighted, unsigned int &list, bool force_quick_search,
+        int nlimit);
 
     void deRefList(size_t item);
 
