@@ -135,7 +135,7 @@ bool StoryBoard::readFile(const char *filename, ListMeta &LM, bool is_top) {
             if ((oldf = getFunctID(temp)) > 0) {
                 if (oldf > SB_BI_FUNC_BASE) {   // overloadng buildin action
                     if (!is_daemonised) {
-                        std::cerr << thread_id << "SB: error - reserved word used a function name - " << temp.c_str() << std::endl;
+                        std::cerr << thread_id << "SB: error - reserved word used a function name - " << filename << " word " << temp.c_str() << std::endl;
                     }
                     syslog(LOG_ERR, "%sSB: error - reserved word used a function name - %s", thread_id.c_str(),
                              temp.c_str());
@@ -237,7 +237,7 @@ bool StoryBoard::readFile(const char *filename, ListMeta &LM, bool is_top) {
                 bool found = false;
                 for (std::deque<int>::iterator k = types.begin(); k != types.end(); k++) {
 #ifdef DGDEBUG
-                                        std::cerr << "SB  list name " << j->list_name << " checking type  " << *k << std::endl;
+                                        std::cerr << "SB  list name " << filename << " list " << j->list_name << " checking type  " << *k << std::endl;
 #endif
                     ListMeta::list_info listi = LMeta->findList(j->list_name, *k);
 #ifdef DGDEBUG
@@ -251,7 +251,7 @@ bool StoryBoard::readFile(const char *filename, ListMeta &LM, bool is_top) {
                 }
                 if (!found) {
                     // warning message
-                    std::cerr << thread_id << "SB warning: Undefined list " << j->list_name << " used at line " << j->file_lineno
+                    std::cerr << thread_id << "SB warning: Undefined list " << filename << " list " << j->list_name << " used at line " << j->file_lineno
                               << " of " << i->file_name << std::endl;
                 } else {
 #ifdef DGDEBUG
@@ -263,7 +263,7 @@ bool StoryBoard::readFile(const char *filename, ListMeta &LM, bool is_top) {
             // check action
             if ((j->action_id = getFunctID(j->action_name)) == 0) {
                 // warning message
-                std::cerr << "StoryBoard error: Action not defined " << j->action_name << " at line " << j->file_lineno
+                std::cerr << "StoryBoard error: Action not defined: " << filename << " action " << j->action_name << " at line " << j->file_lineno
                           << " of " << i->file_name << std::endl;
             }
 #ifdef DGDEBUG
@@ -653,9 +653,12 @@ bool StoryBoard::runFunct(unsigned int fID, NaughtyFilter &cm) {
                     cm.isBlocked = true;
                     cm.isGrey = false;
                     cm.isexception = false;
-                    cm.whatIsNaughty = o.language_list.getTranslation(cm.message_no) + cm.lastmatch;
+                    if( cm.message_no == 503)
+                        cm.whatIsNaughty = o.language_list.getTranslation(cm.message_no) ;
+                    else
+                        cm.whatIsNaughty = o.language_list.getTranslation(cm.message_no) + cm.lastmatch;
                     if (cm.log_message_no == 0)
-                        cm.whatIsNaughtyLog = cm.whatIsNaughty;
+                        cm.whatIsNaughtyLog = o.language_list.getTranslation(cm.message_no) + cm.lastmatch;
                     else
                         cm.whatIsNaughtyLog = o.language_list.getTranslation(cm.log_message_no) + cm.lastmatch;
                     cm.whatIsNaughtyCategories = cm.lastcategory;
@@ -852,12 +855,12 @@ bool StoryBoard::runFunctEntry(unsigned int index, NaughtyFilter &cm) {
 std::deque<url_rec> StoryBoard::deep_urls(String &urld, NaughtyFilter &cm) {
     std::deque<url_rec> temp;
     String durl = urld;
-    while (durl.contains(":")) {
+    while (durl.contains(":") && durl.contains(".")) {
         durl = durl.after(":");
         while (durl.startsWith(":'") || durl.startsWith("/")) {
             durl.lop();
         }
-        if (durl.size() > 0) {
+        if (durl.size() > 3) {
             url_rec t;
             t.baseurl = durl;
             t.baseurl.removePTP();
@@ -870,6 +873,8 @@ std::deque<url_rec> StoryBoard::deep_urls(String &urld, NaughtyFilter &cm) {
             if (cm.isIPHostnameStrip(t.urldomain))
                 t.site_is_ip = true;
             temp.push_back(t);
+        } else {
+            break;
         }
     }
     return temp;
