@@ -14,6 +14,8 @@
 
 #include <syslog.h>
 
+extern thread_local std::string thread_id;
+
 // DECLARATIONS
 
 // class name is relevant!
@@ -24,8 +26,9 @@ class digestinstance : public AuthPlugin
         : AuthPlugin(definition)
     {
         needs_proxy_query = true;
+        client_ip_based = false;
     };
-    int identify(Socket &peercon, Socket &proxycon, HTTPHeader &h, std::string &string);
+    int identify(Socket &peercon, Socket &proxycon, HTTPHeader &h, std::string &string, bool &is_real_user);
 };
 
 // IMPLEMENTATION
@@ -40,7 +43,7 @@ AuthPlugin *digestcreate(ConfigVar &definition)
 // end of Class factory
 
 // proxy auth header username extraction
-int digestinstance::identify(Socket &peercon, Socket &proxycon, HTTPHeader &h, std::string &string)
+int digestinstance::identify(Socket &peercon, Socket &proxycon, HTTPHeader &h, std::string &string, bool &is_real_user)
 {
     // don't match for non-digest auth types
     String t = h.getAuthType();
